==> cdktf-0.9.0.dev6.tar.gz: package/lib/terraform-resource.d.ts <==
import { Construct } from "constructs";
import { TerraformElement } from "./terraform-element";
import { TerraformProvider } from "./terraform-provider";
import { ITerraformDependable } from "./terraform-dependable";
import { IResolvable } from "./tokens/resolvable";
/**
 * @experimental
 */
export interface ITerraformResource {
    /**
     * @experimental
     */
    readonly terraformResourceType: string;
    /**
     * @experimental
     */
    readonly fqn: string;
    /**
     * @experimental
     */
    readonly friendlyUniqueId: string;
    /**
     * @experimental
     */
    dependsOn?: string[];
    /**
     * @experimental
     */
    count?: number | IResolvable;
    /**
     * @experimental
     */
    provider?: TerraformProvider;
    /**
     * @experimental
     */
    lifecycle?: TerraformResourceLifecycle;
    /**
     * @experimental
     */
    interpolationForAttribute(terraformAttribute: string): IResolvable;
}
/**
 * @experimental
 */
export interface TerraformResourceLifecycle {
    /**
     * @experimental
     */
    readonly createBeforeDestroy?: boolean;
    /**
     * @experimental
     */
    readonly preventDestroy?: boolean;
    /**
     * @experimental
     */
    readonly ignoreChanges?: string[];
}
/**
 * @experimental
 */
export interface TerraformMetaArguments {
    /**
     * @experimental
     */
    readonly dependsOn?: ITerraformDependable[];
    /**
     * @experimental
     */
    readonly count?: number | IResolvable;
    /**
     * @experimental
     */
    readonly provider?: TerraformProvider;
    /**
     * @experimental
     */
    readonly lifecycle?: TerraformResourceLifecycle;
}
/**
 * @experimental
 */
export interface TerraformProviderGeneratorMetadata {
    /**
     * @experimental
     */
    readonly providerName: string;
    /**
     * @experimental
     */
    readonly providerVersionConstraint?: string;
}
/**
 * @experimental
 */
export interface TerraformResourceConfig extends TerraformMetaArguments {
    /**
     * @experimental
     */
    readonly terraformResourceType: string;
    /**
     * @experimental
     */
    readonly terraformGeneratorMetadata?: TerraformProviderGeneratorMetadata;
}
/**
 * @experimental
 */
export declare class TerraformResource extends TerraformElement implements ITerraformResource, ITerraformDependable {
    /**
     * @experimental
     */
    readonly terraformResourceType: string;
    /**
     * @experimental
     */
    readonly terraformGeneratorMetadata?: TerraformProviderGeneratorMetadata;
    /**
     * @experimental
     */
    dependsOn?: string[];
    /**
     * @experimental
     */
    count?: number | IResolvable;
    /**
     * @experimental
     */
    provider?: TerraformProvider;
    /**
     * @experimental
     */
    lifecycle?: TerraformResourceLifecycle;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, config: TerraformResourceConfig);
    /**
     * @experimental
     */
    getStringAttribute(terraformAttribute: string): string;
    /**
     * @experimental
     */
    getNumberAttribute(terraformAttribute: string): number;
    /**
     * @experimental
     */
    getListAttribute(terraformAttribute: string): string[];
    /**
     * @experimental
     */
    getBooleanAttribute(terraformAttribute: string): IResolvable;
    /**
     * @experimental
     */
    get fqn(): string;
    /**
     * @experimental
     */
    get terraformMetaArguments(): {
        [name: string]: any;
    };
    /**
     * @experimental
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    /**
     * (experimental) Adds this resource to the terraform JSON output.
     *
     * @experimental
     */
    toTerraform(): any;
    /**
     * @experimental
     */
    toMetadata(): any;
    /**
     * @experimental
     */
    interpolationForAttribute(terraformAttribute: string): IResolvable;
}

==> cdktf-0.11.0.dev4.tar.gz: package/lib/terraform-resource.d.ts <==
import { Construct } from "constructs";
import { TerraformElement } from "./terraform-element";
import { TerraformProvider } from "./terraform-provider";
import { ITerraformDependable } from "./terraform-dependable";
import { IResolvable } from "./tokens/resolvable";
import { IInterpolatingParent } from "./terraform-addressable";
export interface ITerraformResource {
    readonly terraformResourceType: string;
    readonly fqn: string;
    readonly friendlyUniqueId: string;
    dependsOn?: string[];
    count?: number;
    provider?: TerraformProvider;
    lifecycle?: TerraformResourceLifecycle;
    interpolationForAttribute(terraformAttribute: string): IResolvable;
}
export interface TerraformResourceLifecycle {
    readonly createBeforeDestroy?: boolean;
    readonly preventDestroy?: boolean;
    readonly ignoreChanges?: string[];
}
export interface TerraformMetaArguments {
    readonly dependsOn?: ITerraformDependable[];
    readonly count?: number;
    readonly provider?: TerraformProvider;
    readonly lifecycle?: TerraformResourceLifecycle;
}
export interface TerraformProviderGeneratorMetadata {
    readonly providerName: string;
    readonly providerVersionConstraint?: string;
    readonly providerVersion?: string;
}
export interface TerraformResourceConfig extends TerraformMetaArguments {
    readonly terraformResourceType: string;
    readonly terraformGeneratorMetadata?: TerraformProviderGeneratorMetadata;
}
export declare class TerraformResource extends TerraformElement implements ITerraformResource, ITerraformDependable, IInterpolatingParent {
    readonly terraformResourceType: string;
    readonly terraformGeneratorMetadata?: TerraformProviderGeneratorMetadata;
    dependsOn?: string[];
    count?: number;
    provider?: TerraformProvider;
    lifecycle?: TerraformResourceLifecycle;
    readonly fqn: string;
    constructor(scope: Construct, id: string, config: TerraformResourceConfig);
    getStringAttribute(terraformAttribute: string): string;
    getNumberAttribute(terraformAttribute: string): number;
    getListAttribute(terraformAttribute: string): string[];
    getBooleanAttribute(terraformAttribute: string): IResolvable;
    getNumberListAttribute(terraformAttribute: string): number[];
    getStringMapAttribute(terraformAttribute: string): {
        [key: string]: string;
    };
    getNumberMapAttribute(terraformAttribute: string): {
        [key: string]: number;
    };
    getBooleanMapAttribute(terraformAttribute: string): {
        [key: string]: boolean;
    };
    getAnyMapAttribute(terraformAttribute: string): {
        [key: string]: any;
    };
    get terraformMetaArguments(): {
        [name: string]: any;
    };
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    /**
     * Adds this resource to the terraform JSON output.
     */
    toTerraform(): any;
    toMetadata(): any;
    interpolationForAttribute(terraformAttribute: string): IResolvable;
}
